@@ -18,6 +18,10 @@
 
 #    Copyright (C) 2023, Bruce Schuck <bschuck@asgard-systems.com>
 
+#    Changes:
+#    2024-04-13 - Changed to use
+#    https://query1.finance.yahoo.com/v8/finance/chart/
+
 package Finance::Quote::CurrencyRates::YahooJSON;
 
 use strict;
@@ -28,10 +32,10 @@ use if DEBUG, 'Smart::Comments';
 
 use JSON;
 
-our $VERSION = '1.58_01'; # TRIAL VERSION
+our $VERSION = '1.59_01'; # TRIAL VERSION
 
-my $YIND_URL_HEAD = 'https://query2.finance.yahoo.com/v11/finance/quoteSummary/?symbol=';
-my $YIND_URL_TAIL = '&modules=price';
+my $YIND_URL_HEAD = 'https://query1.finance.yahoo.com/v8/finance/chart/';
+my $YIND_URL_TAIL = '?metrics=high&interval=1d&range=1d';
 
 sub new
 {
@@ -69,12 +73,12 @@ sub multipliers
 
   ### JSON: $json_data
 
-  if ( !$json_data || !$json_data->{'quoteSummary'}->{'result'}->[0]->{'price'}->{'regularMarketPrice'}{'raw'} ) {
+  if ( !$json_data || !$json_data->{'chart'}->{'result'}->[0]->{'meta'}->{'regularMarketPrice'} ) {
     return;
   }
 
   $rate =
-    $json_data->{'quoteSummary'}->{'result'}->[0]->{'price'}->{'regularMarketPrice'}{'raw'};
+    $json_data->{'chart'}->{'result'}->[0]->{'meta'}->{'regularMarketPrice'};
 
   ### Rate from JSON: $rate
 
