@@ -1,8 +1,19 @@
 #!/usr/bin/perl -w
 
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
 #
-# Initial version based on IndiaMutual.pm
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
 #
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+#    02110-1301, USA
 
 package Finance::Quote::NSEIndia;
 require 5.010;
@@ -11,16 +22,15 @@ use strict;
 use POSIX qw(strftime);
 use IO::Uncompress::Unzip qw(unzip $UnzipError);
 
-our $VERSION = '1.58_01'; # TRIAL VERSION
+use constant DEBUG => $ENV{DEBUG};
+use if DEBUG, 'Smart::Comments', '###';
+
+our $VERSION = '1.59_01'; # TRIAL VERSION
 
 use vars qw($NSE_MAIN_URL $NSE_URL);
 $NSE_MAIN_URL = "https://www.nseindia.com";
 $NSE_URL = "https://archives.nseindia.com";
 
-my $cachedir = $ENV{TMPDIR} // $ENV{TEMP} // '/tmp/';
-my $NSE_ZIP = $cachedir.'nseindia.zip';
-my $NSE_CSV = $cachedir.'nseindia.csv';
-
 sub methods { return ( 'india' => \&nseindia,
                        'nseindia' => \&nseindia ); }
 
@@ -38,23 +48,29 @@ sub nseindia {
     return unless @symbols;
 
     my (%info, $errormsg, $fh, $ua, $url, $reply);
+	my $output;
+    my @array;
 
     $ua = $quoter->user_agent;
     # Disable redirects - server redirects instead of 404.
     $ua->requests_redirectable([]);
 
+    # Set the ua to be blank. Server blocks default useragent.
+    $ua->agent('');
+    
     my %mnames = ('01' => 'JAN', '02' => 'FEB', '03' => 'MAR', '04' => 'APR', '05' => 'MAY', '06' => 'JUN',
           '07' => 'JUL', '08' => 'AUG', '09' => 'SEP', '10' => 'OCT', '11' => 'NOV', '12' => 'DEC');
     # Try to fetch last 10 days
     for (my ($days, $now) = (0, time()); $days < 10; $days++) {
         # Ex: https://archives.nseindia.com/content/historical/EQUITIES/2020/APR/cm23APR2020bhav.csv.zip
         my @lt = localtime($now - $days*24*60*60);
-        my ($day, $month, $year, $url);
+        my ($day, $month, $year, $url, $req, $output);
         $day = strftime "%d", @lt;
         $month = $mnames{strftime "%m", @lt}; # Can't use %b as it's locale dependent.
         $year = strftime "%Y", @lt;
         $url = $NSE_URL . "/content/historical/EQUITIES/$year/$month/cm$day$month${year}bhav.csv.zip";
-        $reply = $ua->mirror($url, $NSE_ZIP);
+        $req = HTTP::Request->new(GET => $url);     #added for fileless
+        $reply = $ua->request($req);
         # print "$url", $reply->is_success, $reply->status_line, "\n"; #DEBUG
         if ($reply->is_success or $reply->code == 304) {
             last;
@@ -66,15 +82,12 @@ sub nseindia {
     }
 
     if (!$errormsg) {
-        if (! unzip $NSE_ZIP => $NSE_CSV) {
+ 		#Does not use temp files. Fileless into variable $output
+        if (! unzip \$reply->content => \$output) {
             $errormsg = "Unzip error : $UnzipError";
-        }
-    }
-
-    if (!$errormsg) {
-        if (! open $fh, '<', $NSE_CSV) {
-            $errormsg = "CSV open error: $!";
-        }
+        } else {
+			@array = split("\n", $output);
+		}
     }
 
     if ($errormsg) {
@@ -89,49 +102,48 @@ sub nseindia {
     my %symbolhash;
     foreach my $symbol (@symbols)
     {
-    $symbolhash{$symbol} = 0;
+		$symbolhash{$symbol} = 0;
     }
     my $csvhead;
     my @headhash;
 
     # SYMBOL,SERIES,OPEN,HIGH,LOW,CLOSE,LAST,PREVCLOSE,TOTTRDQTY,TOTTRDVAL,TIMESTAMP,TOTALTRADES,ISIN,
-    $csvhead = <$fh>;
-    chomp $csvhead;
+    $csvhead = $array[0];
+
     @headhash = split /\s*,s*/, $csvhead;
-    while (<$fh>) {
-    my @data = split /\s*,s*/;
-    my %datahash;
-    my $symbol;
-    @datahash{@headhash} = @data;
-    if (exists $symbolhash{$datahash{"SYMBOL"}}) {
-        $symbol = $datahash{"SYMBOL"};
+    foreach (@array) {
+		my @data = split /\s*,s*/;
+		my %datahash;
+		my $symbol;
+		@datahash{@headhash} = @data;
+		if (exists $symbolhash{$datahash{"SYMBOL"}}) {
+			$symbol = $datahash{"SYMBOL"};
+		}
+		elsif(exists $symbolhash{$datahash{"ISIN"}}) {
+			$symbol = $datahash{"ISIN"};
+		}
+		else {
+			next;
+		}
+		$info{$symbol, 'symbol'} = $symbol;
+		$info{$symbol, 'close'} = $datahash{"CLOSE"};
+		$info{$symbol, 'last'} = $datahash{"LAST"};
+		$info{$symbol, 'high'} = $datahash{"HIGH"};
+		$info{$symbol, 'low'} = $datahash{"LOW"};
+		$info{$symbol, 'open'} = $datahash{"OPEN"};
+		$info{$symbol, 'prevclose'} = $datahash{"PREVCLOSE"};
+		$quoter->store_date(\%info, $symbol, {eurodate => $datahash{"TIMESTAMP"}});
+		$info{$symbol, 'method'} = 'nseindia';
+		$info{$symbol, 'currency'} = 'INR';
+		$info{$symbol, 'exchange'} = 'NSE';
+		$info{$symbol, 'success'} = 1;
     }
-    elsif(exists $symbolhash{$datahash{"ISIN"}}) {
-        $symbol = $datahash{"ISIN"};
-    }
-    else {
-        next;
-    }
-    $info{$symbol, 'symbol'} = $symbol;
-    $info{$symbol, 'close'} = $datahash{"CLOSE"};
-    $info{$symbol, 'last'} = $datahash{"LAST"};
-    $info{$symbol, 'high'} = $datahash{"HIGH"};
-    $info{$symbol, 'low'} = $datahash{"LOW"};
-    $info{$symbol, 'open'} = $datahash{"OPEN"};
-    $info{$symbol, 'prevclose'} = $datahash{"PREVCLOSE"};
-    $quoter->store_date(\%info, $symbol, {eurodate => $datahash{"TIMESTAMP"}});
-    $info{$symbol, 'method'} = 'nseindia';
-    $info{$symbol, 'currency'} = 'INR';
-    $info{$symbol, 'exchange'} = 'NSE';
-    $info{$symbol, 'success'} = 1;
-    }
-    close($fh);
 
     foreach my $symbol (@symbols) {
         unless (exists $info{$symbol, 'success'}) {
-        $info{$symbol, 'success'} = 0;
-        $info{$symbol, 'errormsg'} = 'Stock not found on NSE.';
-    }
+			$info{$symbol, 'success'} = 0;
+			$info{$symbol, 'errormsg'} = 'Stock not found on NSE.';
+		}
     }
 
     return wantarray ? %info : \%info;
