@@ -26,7 +26,7 @@ use if DEBUG, 'Smart::Comments';
 use LWP::UserAgent;
 use Web::Scraper;
 
-our $VERSION = '1.58_01'; # TRIAL VERSION
+our $VERSION = '1.59_01'; # TRIAL VERSION
 
 my $Tradegate_URL = 'https://web.s-investor.de/app/detail.htm?boerse=TDG&isin=';
 
@@ -69,32 +69,31 @@ sub tradegate {
       my $symlen = length($symbol);
 
       my $tree = HTML::TreeBuilder->new_from_url($url);
-      
-      my $lastvalue = $tree->look_down('class'=>'si_seitenbezeichnung');
-      my @child = $lastvalue->content_list;
 
-      if ($child[0] eq 'S-Investor Ausnahme') {
+      my $lastvalue = $tree->look_down('class'=>'si_seitenbezeichnung');
+
+      if (defined($lastvalue)) {
         $info{ $symbol, 'success' } = 0;
         $info{ $symbol, 'errormsg' } = 'Invalid institute id. Get a valid institute id from https://web.s-investor.de/app/webauswahl.jsp';
       } else {
-        $lastvalue = $tree->look_down('class'=>'si_inner_content_box');
-  
+        $lastvalue = $tree->look_down('id'=>'kursdaten');
+
         my $td1 = ($lastvalue->look_down('_tag'=>'td'))[1];
-        @child = $td1->content_list;
-        my $isin =$child[0];
-  
+        my @child = $td1->content_list;
+        my $isin = $child[0];
+
         $td1 = ($lastvalue->look_down('_tag'=>'td'))[3];
         @child = $td1->content_list;
         my $sharename = $child[0];
-  
+
         $td1 = ($lastvalue->look_down('_tag'=>'td'))[5];
         @child = $td1->content_list;
         my $exchange = $child[0];
-  
+
         $td1 = ($lastvalue->look_down('_tag'=>'td'))[7];
         @child = $td1->content_list;
         my $date = substr($child[0], 0, 8);
-  
+
         $td1 = ($lastvalue->look_down('_tag'=>'td'))[9];
         @child = $td1->content_list;
         my $price = $child[0];
@@ -103,60 +102,73 @@ sub tradegate {
         my $encprice = encode_entities($price);
         my @splitprice= split ('&',$encprice);
         $price = $splitprice[0];
-  
+
         $td1 = ($lastvalue->look_down('_tag'=>'td'))[11];
         @child = $td1->content_list;
         my $currency = $child[0];
         $currency =~ s/Euro/EUR/;
-  
+
         $td1 = ($lastvalue->look_down('_tag'=>'td'))[13];
         @child = $td1->content_list;
         my $volume = $child[0];
-  
-        $lastvalue = $tree->look_down('id'=>'detailVergleichszahlen');
-  
-        #-- change (absolute change)
-        $td1 = ($lastvalue->look_down('_tag'=>'td'))[16];
-        @child = $td1->content_list;
-        my $change =$child[0];
-        $change =~ s/\.//g;
-        $change =~ s/,/\./;
-        my $encchange = encode_entities($change);
-        my @splitcchange= split ('&',$encchange);
-        $change = $splitcchange[0];
-  
-        #-- p_change (relative change)
-        $td1 = ($lastvalue->look_down('_tag'=>'td'))[19];
-        @child = $td1->content_list;
-        my $p_change =$child[0];
-        $p_change =~ s/[\.|%]//g;
-        $p_change =~ s/,/\./;
-  
-        #-- close
-        $td1 = ($lastvalue->look_down('_tag'=>'td'))[37];
-        @child = $td1->content_list;
-        my $close =$child[0];
-        $close =~ s/\.//g;
-        $close =~ s/,/\./;
-        my $encclose = encode_entities($close);
-        my @splitclose= split ('&',$encclose);
-        $close = $splitclose[0];
-  
-  
-        $info{$symbol, 'success'}   = 1;
-        $info{$symbol, 'method'}    = 'Tradegate';
-        $info{$symbol, 'symbol'}    = $isin;
-        $info{$symbol, 'name'}      = $sharename;
-        $info{$symbol, 'exchange'}  = $exchange;
-        $info{$symbol, 'last'}      = $price;
-        $info{$symbol, 'price'}     = $price;
-        $info{$symbol, 'close'}     = $close;
-        $info{$symbol, 'change'}    = $change;
-        $info{$symbol, 'p_change'}  = $p_change;
-        $info{$symbol, 'volume'}    = $volume;
-        $info{$symbol, 'currency'}  = $currency;
-  #      $info{$symbol, 'date'}     = $date;
-        $quoter->store_date(\%info, $symbol, {eurodate => $date});
+
+        my @searchvalue = $tree->look_down('class'=>'contentBox oneColum');
+        my $isFound = 0;
+        foreach (@searchvalue)
+        {
+          if (($_->content_list)[0]{'_content'}[0]{'_content'}[0] eq 'Aktuelle Vergleichszahlen')
+          {
+            $isFound = 1;
+
+            #-- change (absolute change)
+            $td1 = ($_->look_down('_tag'=>'td'))[13];
+            @child = $td1->content_list;
+            my $change = $child[0];
+            $change =~ s/\.//g;
+            $change =~ s/,/\./;
+            my $encchange = encode_entities($change);
+            my @splitcchange= split ('&',$encchange);
+            $change = $splitcchange[0];
+
+            #-- p_change (relative change)
+            $td1 = ($_->look_down('_tag'=>'td'))[16];
+            @child = $td1->content_list;
+            my $p_change =$child[0];
+            $p_change =~ s/[\.|%]//g;
+            $p_change =~ s/,/\./;
+
+            #-- close
+            $td1 = ($_->look_down('_tag'=>'td'))[34];
+            @child = $td1->content_list;
+            my $close = $child[0];
+            $close =~ s/\.//g;
+            $close =~ s/,/\./;
+            my $encclose = encode_entities($close);
+            my @splitclose= split ('&',$encclose);
+            $close = $splitclose[0];
+
+            $info{$symbol, 'success'}   = 1;
+            $info{$symbol, 'method'}    = 'Tradegate';
+            $info{$symbol, 'symbol'}    = $isin;
+            $info{$symbol, 'name'}      = $sharename;
+            $info{$symbol, 'exchange'}  = $exchange;
+            $info{$symbol, 'last'}      = $price;
+            $info{$symbol, 'price'}     = $price;
+            $info{$symbol, 'close'}     = $close;
+            $info{$symbol, 'change'}    = $change;
+            $info{$symbol, 'p_change'}  = $p_change;
+            $info{$symbol, 'volume'}    = $volume;
+            $info{$symbol, 'currency'}  = $currency;
+            #$info{$symbol, 'date'}     = $date;
+            $quoter->store_date(\%info, $symbol, {eurodate => $date});
+          }
+        }
+
+        if (!$isFound)
+        {
+           $info{$symbol, 'success'}  = 0;
+           $info{$symbol, 'errormsg'} = "Error retreiving $symbol: $@";
+        }
       }
     };
     if ($@) {
@@ -228,5 +240,3 @@ price
 close
 change
 p_change
-
-
